@@ -1,17 +1,58 @@
+"""
+ _______                        __ _______ __        __ __
+|   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
+|.  1___|   _|  _  |  |  |  |  _  |   1___|   _|   _|  |    <|  -__|
+|.  |___|__| |_____|________|_____|____   |____|__| |__|__|__|_____|
+|:  1   |                         |:  1   |
+|::.. . |   CROWDSTRIKE FALCON    |::.. . |    FalconPy
+`-------'                         `-------'
+
+OAuth2 API - Customer SDK
+
+sensor_download - Falcon Sensor Download API Interface Class
+
+This is free and unencumbered software released into the public domain.
+
+Anyone is free to copy, modify, publish, use, compile, sell, or
+distribute this software, either in source code form or as a compiled
+binary, for any purpose, commercial or non-commercial, and by any
+means.
+
+In jurisdictions that recognize copyright laws, the author or authors
+of this software dedicate any and all copyright interest in the
+software to the public domain. We make this dedication for the benefit
+of the public at large and to the detriment of our heirs and
+successors. We intend this dedication to be an overt act of
+relinquishment in perpetuity of all present and future rights to this
+software under copyright law.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+OTHER DEALINGS IN THE SOFTWARE.
+
+For more information, please refer to <https://unlicense.org>
+"""
+import os
 from ._util import service_request, parse_id_list, generate_ok_result
 from ._service_class import ServiceClass
 
-import os
-
 
 class Sensor_Download(ServiceClass):
-
-    def GetCombinedSensorInstallersByQuery(self: object, parameters: dict = {}) -> dict:
+    """The only requirement to instantiate an instance of this class
+       is a valid token provided by the Falcon API SDK OAuth2 class.
+    """
+    def GetCombinedSensorInstallersByQuery(self: object, parameters: dict = None) -> dict:
         """
-        retrieve all metadata for installers from provided query
+        Retrieve all metadata for installers from provided query
         """
         FULL_URL = self.base_url+'/sensors/combined/installers/v1'
         HEADERS = self.headers
+        if parameters is None:
+            parameters = {}
         PARAMS = parameters
         returned = service_request(caller=self,
                                    method="GET",
@@ -28,8 +69,8 @@ class Sensor_Download(ServiceClass):
                                     download_path: str = None
                                     ) -> object:
         """
-        download the sensor by the sha256 into the specified directory.
-        the path will be created for the user if it does not already exist
+        Download the sensor by the sha256 id, into the specified directory.
+        The path will be created for the user if it does not already exist
         """
         FULL_URL = self.base_url+"/sensors/entities/download-installer/v1"
         HEADERS = self.headers
@@ -67,7 +108,7 @@ class Sensor_Download(ServiceClass):
 
     def GetSensorInstallersCCIDByQuery(self: object) -> dict:
         """
-        retrieve the CID for the current oauth environment
+        Retrieve the CID for the current oauth environment
         """
         FULL_URL = self.base_url+'/sensors/queries/installers/ccid/v1'
         HEADERS = self.headers
@@ -79,12 +120,14 @@ class Sensor_Download(ServiceClass):
                                    )
         return returned
 
-    def GetSensorInstallersByQuery(self: object, parameters: dict = {}) -> dict:
+    def GetSensorInstallersByQuery(self: object, parameters: dict = None) -> dict:
         """
-        retrieve a list of SHA256 for installers based on the filter
+        Retrieve a list of SHA256 for installers based on the filter
         """
         FULL_URL = self.base_url+'/sensors/queries/installers/v1'
         HEADERS = self.headers
+        if parameters is None:
+            parameters = {}
         PARAMS = parameters
         returned = service_request(caller=self,
                                    method="GET",
